@@ -1,5 +1,5 @@
 from disco.core.exceptions import GraphQLRequestException
-from disco.models import JobDetails
+from disco.models import JobDetails, Task
 
 MockListJobsResponse = [
     JobDetails({'id': '5df8db9f099035000c7b0c87', 'status': 'Done', 'request': {'meta': {'name': 'dsfgfdsgs'}}}),
@@ -47,3 +47,14 @@ MockBadIdException = GraphQLRequestException("", [
                                                                                         'locations': [],
                                                                                         'path': [
                                                                                             'fetchJob']}]}}}])
+
+MockListTasksResponse = [
+    Task({'id': '5e4bef1942abec000cab2a71', 'status': 'Success', 'stats': {'duration': 17602}, 'request':
+        {'inputFile': {'id': '5e4beee087b4b2000edc6f2e'}}, 'result': {'artifactIds': ['5e53a8cc5ccc95000cfffa1d']}}),
+    Task({'id': '5e4bef1942abec000cab2a72', 'status': 'Success', 'stats': {'duration': 1023}, 'request':
+        {'inputFile': {'id': '5e4beee987b4b2000edc6f30'}}, 'result': {'artifactIds': ['5e53a8bc3b64ee000b87d4a4']}}),
+    Task({'id': '5e4bef1942abec000cab2a73', 'status': 'Success', 'stats': {'duration': 1008}, 'request':
+        {'inputFile': {'id': '5e4beef687b4b2000edc6f32'}}, 'result': {'artifactIds': ['5e53a8b85ccc95000cfffa1b']}}),
+    Task({'id': '5e4bef1942abec000cab2a74', 'status': 'Success', 'stats': {'duration': 3626}, 'request':
+        {'inputFile': {'id': '5e4beefd2bb7d7000b92cdf8'}}, 'result': {'artifactIds': ['5e53a8c03b64ee000b87d4a6']}})
+]
